@@ -78,6 +78,8 @@ KitaMainWindow::KitaMainWindow()
   // position, icon size, etc.
   setAutoSaveSettings();
 
+  readDockConfig( KGlobal::config() );
+
   readConfig(KGlobal::config());
 
   // allow the view to change the statusbar and caption
@@ -119,6 +121,7 @@ KitaMainWindow::KitaMainWindow()
   connect( popup, SIGNAL( aboutToShow() ), SLOT( windowMenuAboutToShow() ) );
 
   m_boardView->loadBoardList();
+  m_boardView->setFocus();
 }
 
 KitaMainWindow::~KitaMainWindow()
@@ -127,6 +130,8 @@ KitaMainWindow::~KitaMainWindow()
 
   saveCache();
   writeConfig(KGlobal::config());
+
+  writeDockConfig( KGlobal::config() );
 }
 
 void KitaMainWindow::load(const KURL& url)
