@@ -32,13 +32,13 @@ class KitaBoardView : public KitaBoardViewBase
   Q_OBJECT
 
   QString getCategory(const QString& line) const;
-  Kita::Board getBoard(const QString& line) const;
+  Kita::Board* getBoard(const QString& line) const;
   bool isBoardUrl(const KURL& url) const;
   QPtrList<Kita::Category> getCategoryList(const QString& html) const;
-  void printCateogryList(QPtrList<Kita::Category>& list);
 
 private slots:
   void loadBoard(QListViewItem* item);
+  void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
 
 public:
   KitaBoardView(QWidget *parent, const char *name=0);
@@ -49,7 +49,7 @@ public slots:
   void setFont( const QFont& font );
 
 signals:
-  void clicked( const Kita::Board& board );
+  void clicked( const Kita::Board* board );
 };
 
 #endif
