@@ -75,6 +75,8 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
                         SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
   connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
                         SLOT( loadThread( int, QListViewItem* ) ) );
+  connect( subjectList, SIGNAL( returnPressed( QListViewItem* ) ),
+                        SLOT( loadThread( QListViewItem* ) ) );
 }
 
 KitaSubjectView::~KitaSubjectView()
@@ -86,6 +88,11 @@ void KitaSubjectView::reloadSubject()
 }
 
 void KitaSubjectView::loadThread( int, QListViewItem* item )
+{
+    loadThread( item );
+}
+
+void KitaSubjectView::loadThread( QListViewItem* item )
 {
   if( ! item ) return;
 
@@ -146,6 +153,8 @@ void KitaSubjectView::loadBoard(const Kita::Board* board)
     HideButton->toggle();
   }
   emit loadBoardCompleted(m_board->url());
+
+  subjectList->setFocus();
 }
 
 void KitaSubjectView::slotSearchButton()
