@@ -31,9 +31,10 @@ namespace Kita {
     QString m_boardURL;
     QString m_boardName;
     static QDict<Board>* m_boardDict;
-  public:
-    Board();
     Board(const QString& boardURL, const QString boardName = QString::null);
+  protected:
+    Board();
+  public:
     ~Board();
     const KURL subjectTxtURL() const;
     const QString& url() const;
@@ -42,7 +43,6 @@ namespace Kita {
     const QPtrList<Thread> getThreadList() const;
 
     const QString toXmlFragment() const;
-    static Board fromXml( const QString& xml );
 
     // Factory method
     static Board* getByURL( const QString& boardURL );
@@ -62,7 +62,7 @@ namespace Kita {
     QString m_urlStr;
 
     QString m_characters;
-    Board m_board;
+    Board* m_board;
     bool m_inBoard;
     bool m_isValid;
   public:
@@ -72,7 +72,7 @@ namespace Kita {
     bool endElement( const QString& namespaceURI, const QString& localName, const QString& qName );
     bool characters( const QString& ch );
     bool isValid() const { return m_isValid; }
-    Board getBoard() const { return m_board; }
+    Board* getBoard() const { return m_board; }
   };
 };
 
