@@ -20,12 +20,12 @@ Category::~Category()
 {
 }
 
-void Category::append( const Board& board )
+void Category::append( const Board* board )
 {
   m_boardList.append( board );
 }
 
-const QValueList<Board>& Category::getBoardList() const
+const QPtrList<Board>& Category::getBoardList() const
 {
   return m_boardList;
 }
