@@ -12,6 +12,8 @@
 
 #include <kdebug.h>
 
+#include "threadinfo.h"
+
 FavoriteThreads* FavoriteThreads::instance = 0;
 
 FavoriteThreads::FavoriteThreads()
@@ -32,8 +34,8 @@ FavoriteThreads* FavoriteThreads::getInstance()
 
 void FavoriteThreads::insert( const Kita::Thread* thread )
 {
-  if( ! m_threadDict.find( thread->datURL().url() ) ) {
-    m_threadDict.insert( thread->datURL().url(), thread );
+  if( ! m_threadDict.find( thread->datURL() ) ) {
+    m_threadDict.insert( thread->datURL(), thread );
   }
 }
 
@@ -158,7 +160,8 @@ bool FavoritesXmlParser::endElement( const QString& namespaceURI, const QString&
     m_inThread = false;
     m_threadParser->endElement( namespaceURI, localName, qName );
     Kita::Thread thread = m_threadParser->getThread();
-    m_threadList.append( new Kita::Thread( thread.datURL(), thread.name(), thread.resNum() ) );
+    m_threadList.append( new Kita::Thread( thread.datURL(), thread.name() ) );
+    KitaThreadInfo::setResNum( thread.datURL(), thread.resNum() );
 
     delete m_threadParser;
     m_threadParser = 0;
