@@ -14,6 +14,8 @@
 #include "k2ch_articlefiletest.h"
 #include "urlconverttest.h"
 #include "commenttest.h"
+#include "threadtest.h"
+#include "boardtest.h"
 
 int main( int argc, char* argv[] )
 {
@@ -22,6 +24,8 @@ int main( int argc, char* argv[] )
   runner.addTest( K2chArticleFileTest::suite() );
   runner.addTest( URLConvertTest::suite() );
   runner.addTest( CommentTest::suite() );
+  runner.addTest( ThreadTest::suite() );
+  runner.addTest( BoardTest::suite() );
   runner.run( "" );
   return 0;
 }
