@@ -20,6 +20,7 @@ class KitaConfig{
   static KitaConfig* instance;
   QFont m_font;
   QFont m_threadFont;
+  QString m_boardListURL;
   KitaConfig();
   virtual ~KitaConfig();
 public:
@@ -28,6 +29,8 @@ public:
   static void setFont(QFont font) { getInstance()->m_font = font; }
   static QFont& threadFont() { return getInstance()->m_threadFont; }
   static void setThreadFont( QFont font ) { getInstance()->m_threadFont = font; }
+  static void setBoardListURL( QString url ) { getInstance()->m_boardListURL = url; }
+  static QString& boardListURL() { return getInstance()->m_boardListURL; }
 };
 
 #endif
