@@ -32,6 +32,7 @@
 #include <qtextbrowser.h>
 #include <qmessagebox.h>
 #include <qdatetime.h>
+#include <qeucjpcodec.h>
 
 #include "kitahtmlpart.h"
 #include "kitawritedialog.h"
@@ -196,7 +197,8 @@ void KitaThreadView::update( const QString& result )
     text += comment.toHtml(num);
 
     if( prevResNum == num ) {
-      text += QString::fromLocal8Bit( kokomade_yonda );
+      QTextCodec* codec = QTextCodec::codecForName( "euc-jp" );
+      text += codec->toUnicode( kokomade_yonda );
     }
 
     if( (step+=line.length()) > next ) {
@@ -253,6 +255,8 @@ const QString KitaThreadView::footer( int prevResNum ) const
 
 void KitaThreadView::slotShowErrorDialog( const QString& input, const KURL& )
 {
+  QTextCodec* eucjpCodec = QTextCodec::codecForName( "euc-jp" );
+
   kdDebug() << "'" << input << "'" << endl;
   Kita::WriteResult writeResult(input);
 
@@ -270,8 +274,8 @@ void KitaThreadView::slotShowErrorDialog( const QString& input, const KURL& )
     KMessageBox::error(0, writeResult.message(), writeResult.title());
     break;
   case Kita::K2ch_Cookie:
-    if( KMessageBox::questionYesNo(0, QString::fromLocal8Bit(cookie_message),
-                                      QString::fromLocal8Bit(cookie_title)) == KMessageBox::Yes) {
+    if( KMessageBox::questionYesNo(0, eucjpCodec->toUnicode( cookie_message ),
+                                      eucjpCodec->toUnicode( cookie_title ) ) == KMessageBox::Yes) {
       KitaWriteDialog* dialog = openDialog( m_postInfo );
       dialog->postMessage();
     } else {
