@@ -123,7 +123,7 @@ KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info,
 
   new_dlg->boardNameLabel->setText( thread.boardName() );
   new_dlg->threadNameLabel->setText( thread.name() );
-  new_dlg->threadURLLabel->setText( thread.url().url() );
+  new_dlg->threadURLLabel->setText( thread.url() );
 
   new_dlg->setCaption( i18n("Write in %1").arg( thread.name() ) );
   return new_dlg;
